@@ -31,6 +31,8 @@ BLACK_PATHS = [
     "setup.py",
 ]
 
+DEFAULT_PYTHON_VERSION = "3.10"
+
 test_dependencies = [
     "django>=2.0.0",
     "google-auth",
@@ -45,8 +47,24 @@ test_dependencies = [
     "coverage",
 ]
 
+nox.options.sessions = [
+    # TODO(https://github.com/googleapis/google-api-python-client/issues/2622):
+    # Remove or restore testing for Python 3.7/3.8
+    "unit-3.9",
+    "unit-3.10",
+    "unit-3.11",
+    "unit-3.12",
+    "unit-3.13",
+    "lint",
+    "format",
+    "scripts",
+]
 
-@nox.session(python=["3.7"])
+# Error if a python version is missing
+nox.options.error_on_missing_interpreters = True
+
+
+@nox.session(python=DEFAULT_PYTHON_VERSION)
 def lint(session):
     session.install("flake8")
     session.run(
@@ -60,7 +78,7 @@ def lint(session):
     )
 
 
-@nox.session(python="3.8")
+@nox.session(python=DEFAULT_PYTHON_VERSION)
 def format(session):
     """
     Run isort to sort imports. Then run black
@@ -80,7 +98,7 @@ def format(session):
     )
 
 
-@nox.session(python=["3.7", "3.8", "3.9", "3.10", "3.11", "3.12"])
+@nox.session(python=["3.7", "3.8", "3.9", "3.10", "3.11", "3.12", "3.13"])
 @nox.parametrize(
     "oauth2client",
     [
@@ -128,7 +146,7 @@ def unit(session, oauth2client):
     )
 
 
-@nox.session(python=["3.9"])
+@nox.session(python=DEFAULT_PYTHON_VERSION)
 def scripts(session):
     session.install(*test_dependencies)
     session.install("-e", ".")
